//
//  GesturesViewController.m
//  Gestures
//
//  Created by John E. Ray on 6/26/10.
//  Copyright John E. Ray 2010. All rights reserved.
//

#import "GesturesViewController.h"


#define originWidth 123.0
#define originHeight 112.0
#define originX 98.0
#define originY 328.0

@implementation GesturesViewController

@synthesize tapView;
@synthesize swipeView;
@synthesize pinchView;
@synthesize rotateView;
@synthesize outputLabel;
@synthesize imageView;


- (void)foundTap:(UITapGestureRecognizer *)recognizer {
    outputLabel.text=@"Tapped";
}

- (void)foundSwipe:(UISwipeGestureRecognizer *)recognizer {
    outputLabel.text=@"Swiped";
}

- (void)motionEnded:(UIEventSubtype)motion withEvent:(UIEvent *)event {
    if (motion==UIEventSubtypeMotionShake) {
        outputLabel.text=@"Shaking things up!";
        imageView.transform = CGAffineTransformMakeRotation(0.0);
        imageView.frame=CGRectMake(originX,originY,originWidth,originHeight);
    }
}

- (BOOL)canBecomeFirstResponder{
    return YES; 
}

- (void)foundPinch:(UIPinchGestureRecognizer *)recognizer {
    NSString *feedback;
    double scale;
    scale=recognizer.scale;
    imageView.transform = CGAffineTransformMakeRotation(0.0);
    feedback=[[NSString alloc] 
              initWithFormat:@"Pinched, Scale:%1.2f, Velocity:%1.2f",
              recognizer.scale,recognizer.velocity];
    outputLabel.text=feedback;
    imageView.frame=CGRectMake(originX,
                               originY,
                               originWidth*scale,
                               originHeight*scale);
    [feedback release];
}

- (void)foundRotation:(UIRotationGestureRecognizer *)recognizer {
    NSString *feedback;
    double rotation;
    rotation=recognizer.rotation;
    feedback=[[NSString alloc] 
              initWithFormat:@"Rotated, Radians:%1.2f, Velocity:%1.2f",
              recognizer.rotation,recognizer.velocity];
    outputLabel.text=feedback;
    imageView.transform = CGAffineTransformMakeRotation(rotation);
    [feedback release];
}

// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad {
    [super viewDidLoad];
    
    //Taps
    UITapGestureRecognizer *tapRecognizer;
    tapRecognizer=[[UITapGestureRecognizer alloc] 
				   initWithTarget:self
				   action:@selector(foundTap:)];
    tapRecognizer.numberOfTapsRequired=1;
	tapRecognizer.numberOfTouchesRequired=1;
    [tapView addGestureRecognizer:tapRecognizer];
    [tapRecognizer release];
    
    //Swipes
    UISwipeGestureRecognizer *swipeRecognizer;
    swipeRecognizer=[[UISwipeGestureRecognizer alloc] 
					 initWithTarget:self
					 action:@selector(foundSwipe:)];
    swipeRecognizer.direction=UISwipeGestureRecognizerDirectionLeft |
	UISwipeGestureRecognizerDirectionRight;
	swipeRecognizer.numberOfTouchesRequired=1;
    [swipeView addGestureRecognizer:swipeRecognizer];
    [swipeRecognizer release];
    
    //Pinches
    UIPinchGestureRecognizer *pinchRecognizer;
    pinchRecognizer=[[UIPinchGestureRecognizer alloc] 
                     initWithTarget:self
                     action:@selector(foundPinch:)];
    [pinchView addGestureRecognizer:pinchRecognizer];
    [pinchRecognizer release];
    
    //Rotation
    UIRotationGestureRecognizer *rotationRecognizer;
    rotationRecognizer=[[UIRotationGestureRecognizer alloc] 
						initWithTarget:self
						action:@selector(foundRotation:)];
    [rotateView addGestureRecognizer:rotationRecognizer];
    [rotationRecognizer release];
}

- (void)viewDidAppear:(BOOL)animated {
    [self becomeFirstResponder];  // For the shake event
    [super viewDidAppear: animated];
}


/*
// The designated initializer. Override to perform setup that is required before the view is loaded.
- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
    if ((self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil])) {
        // Custom initialization
    }
    return self;
}
*/

/*
// Implement loadView to create a view hierarchy programmatically, without using a nib.
- (void)loadView {
}
*/


/*
// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad {
    [super viewDidLoad];
}
*/


/*
// Override to allow orientations other than the default portrait orientation.
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}
*/

- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;
}


- (void)dealloc {
    [tapView release];
    [swipeView release];
    [pinchView release];
    [rotateView release];
    [outputLabel release];
    [imageView release];
    [super dealloc];
}

@end
