//
//  ColorTiltViewController.m
//  ColorTilt
//
//  Created by John Ray on 7/14/10.
//  Copyright Poisontooth Enterprises 2010. All rights reserved.
//

#import "ColorTiltViewController.h"

@implementation ColorTiltViewController

@synthesize motionManager;
@synthesize toggleAccelerometer;
@synthesize toggleGyroscope;
@synthesize colorView;

- (void)doAcceleration:(CMAcceleration)acceleration {
    
    if (acceleration.x > 1.3) {
        colorView.backgroundColor = [UIColor greenColor];
    } else if (acceleration.x < -1.3) {
        colorView.backgroundColor = [UIColor orangeColor];
    } else if (acceleration.y > 1.3) {
        colorView.backgroundColor = [UIColor redColor];
    } else if (acceleration.y < -1.3) {
        colorView.backgroundColor = [UIColor blueColor];
    } else if (acceleration.z > 1.3) {
        colorView.backgroundColor = [UIColor yellowColor];
    } else if (acceleration.z < -1.3) {
        colorView.backgroundColor = [UIColor purpleColor];
    }
    
    double value = fabs(acceleration.x);
    if (value > 1.0) { value = 1.0;}
    colorView.alpha = value;
}

- (void)doRotation:(CMRotationRate)rotation {
    
    double value = (fabs(rotation.x)+fabs(rotation.y)+fabs(rotation.z))/8.0;
    if (value > 1.0) { value = 1.0;}
    colorView.alpha = value;
    
}

- (IBAction)controlHardware:(id)sender {
    
    if ([toggleAccelerometer isOn]) {
        [motionManager 
             startAccelerometerUpdatesToQueue:[NSOperationQueue currentQueue]
             withHandler:^(CMAccelerometerData *accelData, NSError *error) {
                                [self doAcceleration:accelData.acceleration];
                                }];
	} else {
        [motionManager stopAccelerometerUpdates];
    }
    
    if ([toggleGyroscope isOn] && motionManager.gyroAvailable) {
        [motionManager 
             startGyroUpdatesToQueue:[NSOperationQueue currentQueue] 
             withHandler:^(CMGyroData *gyroData, NSError *error) {
                                [self doRotation:gyroData.rotationRate];
                                }];
    } else {
		[toggleGyroscope setOn:NO animated:YES];
        [motionManager stopGyroUpdates];
    }
}


/*
// The designated initializer. Override to perform setup that is required before the view is loaded.
- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
    if ((self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil])) {
        // Custom initialization
    }
    return self;
}
*/

/*
// Implement loadView to create a view hierarchy programmatically, without using a nib.
- (void)loadView {
}
*/


// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad {
        
    motionManager = [[CMMotionManager alloc] init];
    motionManager.accelerometerUpdateInterval = .01;
    motionManager.gyroUpdateInterval = .01;
    
    [super viewDidLoad];
}



/*
// Override to allow orientations other than the default portrait orientation.
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}
*/

- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;
}


- (void)dealloc {
    [motionManager release];
    [toggleAccelerometer release];
    [toggleGyroscope release];
    [colorView release];
    [super dealloc];
}

@end
