//
//  MediaPlaygroundViewController.m
//  MediaPlayground
//
//  Created by John E. Ray on 7/12/10.
//  Copyright John E. Ray 2010. All rights reserved.
//

#import "MediaPlaygroundViewController.h"

@implementation MediaPlaygroundViewController

@synthesize toggleFullscreen;
@synthesize toggleCamera;
@synthesize soundRecorder;
@synthesize recordButton;
@synthesize musicPlayer;
@synthesize ipodPlayButton;
@synthesize nowPlaying;
@synthesize chosenImage;

-(IBAction)chooseiPod:(id)sender {
	MPMediaPickerController *musicPicker;
	
	[musicPlayer stop];
	nowPlaying.text=@"No Song Playing";
	[ipodPlayButton setTitle:@"Play iPod Music" 
					forState:UIControlStateNormal];
	
	musicPicker = [[MPMediaPickerController alloc] 
				   initWithMediaTypes: MPMediaTypeMusic];
	
	musicPicker.prompt = @"Choose Songs to Play" ;
	musicPicker.allowsPickingMultipleItems = YES;
	musicPicker.delegate = self;
	
	[self presentModalViewController:musicPicker animated:YES];
    [musicPicker release];
}

-(IBAction)playiPod:(id)sender {
	if ([ipodPlayButton.titleLabel.text isEqualToString:@"Play iPod Music"]) {
		[musicPlayer play];
		[ipodPlayButton setTitle:@"Pause iPod Music" 
						forState:UIControlStateNormal];
		nowPlaying.text=[musicPlayer.nowPlayingItem 
						 valueForProperty:MPMediaItemPropertyTitle];
	} else {
		[musicPlayer pause];
		[ipodPlayButton setTitle:@"Play iPod Music" 
						forState:UIControlStateNormal];
		nowPlaying.text=@"No Song Playing";
	}
}

- (void)mediaPicker: (MPMediaPickerController *)mediaPicker 
  didPickMediaItems:(MPMediaItemCollection *)mediaItemCollection {
	[musicPlayer setQueueWithItemCollection: mediaItemCollection];
	[self dismissModalViewControllerAnimated:YES];
}

- (void)mediaPickerDidCancel:(MPMediaPickerController *)mediaPicker {
	[self dismissModalViewControllerAnimated:YES];
}

-(IBAction)recordAudio:(id)sender {
	if ([recordButton.titleLabel.text isEqualToString:@"Record Audio"]) {
		[soundRecorder record];
		[recordButton setTitle:@"Stop Recording" 
					  forState:UIControlStateNormal];
	} else {
		[soundRecorder stop];
		[recordButton setTitle:@"Record Audio" 
					  forState:UIControlStateNormal];
	}
}

-(IBAction)playAudio:(id)sender {
	NSURL *soundFile;
	NSString *tempDir;
	AVAudioPlayer *audioPlayer;
	
	tempDir=NSTemporaryDirectory();
	soundFile=[NSURL fileURLWithPath: 
			   [tempDir stringByAppendingString:@"sound.caf"]];
	
	audioPlayer =  [[AVAudioPlayer alloc] 
					initWithContentsOfURL:soundFile error:nil];
	
	[audioPlayer setDelegate:self];
	[audioPlayer play];
}

- (void)audioPlayerDidFinishPlaying:(AVAudioPlayer *)player successfully:(BOOL)flag {
    [player release];
}


-(IBAction)playMedia:(id)sender {
	NSString *movieFile;
	MPMoviePlayerController *moviePlayer;
	
	movieFile = [[NSBundle mainBundle] 
                 pathForResource:@"movie" ofType:@"m4v"];
	moviePlayer = [[MPMoviePlayerController alloc] 
                   initWithContentURL: [NSURL fileURLWithPath: movieFile]];
	
    [moviePlayer.view setFrame:CGRectMake(145.0, 20.0, 155.0 , 100.0)];
    [self.view addSubview:moviePlayer.view ];
    
    
	[[NSNotificationCenter defaultCenter] addObserver:self
											 selector:@selector(playMediaFinished:)
												 name:MPMoviePlayerPlaybackDidFinishNotification
											   object:moviePlayer];
	
	[moviePlayer play];
    
    if ([toggleFullscreen isOn]) {
        [moviePlayer setFullscreen:YES animated:YES];
	} 
    
}



-(void)playMediaFinished:(NSNotification*)theNotification
{
	MPMoviePlayerController *moviePlayer=[theNotification object];
	
    [[NSNotificationCenter defaultCenter] removeObserver:self
													name:MPMoviePlayerPlaybackDidFinishNotification
												  object:moviePlayer];
	
    [moviePlayer.view removeFromSuperview];
    [moviePlayer release];
}

-(IBAction)chooseImage:(id)sender {
    UIImagePickerController *imagePicker;
    imagePicker = [[UIImagePickerController alloc] init];
        
    if ([toggleCamera isOn]) {
        imagePicker.sourceType=UIImagePickerControllerSourceTypeCamera;
	} else {
        imagePicker.sourceType=UIImagePickerControllerSourceTypePhotoLibrary;
    }
	imagePicker.delegate=self;

    [[UIApplication sharedApplication] setStatusBarHidden:YES];
    [self presentModalViewController:imagePicker animated:YES];
    [imagePicker release]; // new
}

- (void)imagePickerController:(UIImagePickerController *)picker 
didFinishPickingMediaWithInfo:(NSDictionary *)info {
    [[UIApplication sharedApplication] setStatusBarHidden:NO];
    [self dismissModalViewControllerAnimated:YES];
    chosenImage.image=[info objectForKey:
                       UIImagePickerControllerOriginalImage];
}

- (void)imagePickerControllerDidCancel:(UIImagePickerController *)picker {
    [[UIApplication sharedApplication] setStatusBarHidden:NO];
    [self dismissModalViewControllerAnimated:YES];
}

/*
// The designated initializer. Override to perform setup that is required before the view is loaded.
- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
    if ((self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil])) {
        // Custom initialization
    }
    return self;
}
*/

/*
// Implement loadView to create a view hierarchy programmatically, without using a nib.
- (void)loadView {
}
*/


- (void)viewDidLoad {
	NSString *tempDir;
	NSURL *soundFile;
	NSDictionary *soundSetting;
	
	tempDir=NSTemporaryDirectory();
	soundFile=[NSURL fileURLWithPath: 
			   [tempDir stringByAppendingString:@"sound.caf"]];
	
	soundSetting = [NSDictionary dictionaryWithObjectsAndKeys:
					[NSNumber numberWithFloat: 44100.0],AVSampleRateKey,
					[NSNumber numberWithInt: kAudioFormatMPEG4AAC],AVFormatIDKey,
					[NSNumber numberWithInt: 2],AVNumberOfChannelsKey,
					[NSNumber numberWithInt: AVAudioQualityHigh],AVEncoderAudioQualityKey,
					nil];
	
	soundRecorder = [[AVAudioRecorder alloc] initWithURL: soundFile
												settings: soundSetting
												   error: nil];
	
	musicPlayer=[MPMusicPlayerController iPodMusicPlayer]; 
	
    [super viewDidLoad];
}


/*
// Override to allow orientations other than the default portrait orientation.
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}
*/

- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;
}


- (void)dealloc {
    [toggleFullscreen release];
    [toggleCamera release];
	[soundRecorder release];
	[recordButton release];
	[musicPlayer release];
	[ipodPlayButton release];
	[nowPlaying release];
    [chosenImage release];
    [super dealloc];
}

@end
