//
//  BestFriendViewController.m
//  BestFriend
//
//  Created by John Ray on 7/16/10.
//  Copyright Poisontooth Enterprises 2010. All rights reserved.
//

#import "BestFriendViewController.h"

@implementation BestFriendViewController

@synthesize name;
@synthesize photo;
@synthesize email;
@synthesize map;

- (IBAction)sendEmail:(id)sender {
    MFMailComposeViewController *mailComposer;
    NSArray *emailAddresses;
    emailAddresses=[[NSArray alloc]initWithObjects: email.text,nil];
    
    mailComposer=[[MFMailComposeViewController alloc] init];
    mailComposer.mailComposeDelegate=self;
    [mailComposer setToRecipients:emailAddresses];
    [self presentModalViewController:mailComposer animated:YES];
    
    [emailAddresses release];
    [mailComposer release];
}

- (void)mailComposeController:(MFMailComposeViewController*)controller didFinishWithResult:(MFMailComposeResult)result error:(NSError*)error {
    [self dismissModalViewControllerAnimated:YES];
}


- (void)centerMap:(NSString*)zipCode showAddress:(NSDictionary*)fullAddress {
    NSString *queryURL;
    NSString *queryResults;
    NSArray *queryData;
    double latitude;
    double longitude;
    MKCoordinateRegion mapRegion;
    
    queryURL = [[NSString alloc] 
                initWithFormat:
                @"http://maps.google.com/maps/geo?output=csv&q=%@", 
                zipCode];
    
    queryResults = [[NSString alloc] initWithContentsOfURL:
                    [NSURL URLWithString:queryURL]
                                                  encoding: NSUTF8StringEncoding 
                                                     error: nil];
    // Autoreleased
    queryData = [queryResults componentsSeparatedByString:@","];
    
    if([queryData count]==4) {
        latitude=[[queryData objectAtIndex:2] doubleValue];
        longitude=[[queryData objectAtIndex:3] doubleValue];
        //     CLLocationCoordinate2D;
        mapRegion.center.latitude=latitude;
        mapRegion.center.longitude=longitude;
        mapRegion.span.latitudeDelta=0.2;
        mapRegion.span.longitudeDelta=0.2;
        [map setRegion:mapRegion animated:YES];
		
		if (zipAnnotation!=nil) {
			[map removeAnnotation: zipAnnotation];
		}
		zipAnnotation = [[MKPlacemark alloc] initWithCoordinate:mapRegion.center addressDictionary:fullAddress];
        [map addAnnotation:zipAnnotation];
		[zipAnnotation release];
		
		
    }
    
    [queryURL release];
    [queryResults release];
    
}


- (MKAnnotationView *)mapView:(MKMapView *)mapView 
			viewForAnnotation:(id <MKAnnotation>)annotation {
	MKPinAnnotationView *pinDrop=[[MKPinAnnotationView alloc] 
			initWithAnnotation:annotation reuseIdentifier:@"citycenter"];
	pinDrop.animatesDrop=YES;
	pinDrop.canShowCallout=YES;
	pinDrop.pinColor=MKPinAnnotationColorPurple;
	return pinDrop;
}


- (IBAction)newBFF:(id)sender {
	ABPeoplePickerNavigationController *picker;
    
    picker=[[ABPeoplePickerNavigationController alloc] init];
	picker.peoplePickerDelegate = self;
    
    [self presentModalViewController:picker animated:YES];
    
	[picker release];
}

- (void)peoplePickerNavigationControllerDidCancel:
(ABPeoplePickerNavigationController *)peoplePicker {
    [self dismissModalViewControllerAnimated:YES];
}

- (BOOL)peoplePickerNavigationController:
(ABPeoplePickerNavigationController *)peoplePicker
	  shouldContinueAfterSelectingPerson:(ABRecordRef)person {
	
	// Retrieve the friend's name from the address book person record
    NSString *friendName;
    NSString *friendEmail;
    NSString *friendZip;
    
    friendName=(NSString *)ABRecordCopyValue(person, kABPersonFirstNameProperty);
    name.text = friendName;
    [friendName release];
    
    
    ABMultiValueRef friendAddressSet;
	NSDictionary *friendFirstAddress;
    friendAddressSet = ABRecordCopyValue(person, kABPersonAddressProperty);
    
    if (ABMultiValueGetCount(friendAddressSet)>0) {
        friendFirstAddress = (NSDictionary *)ABMultiValueCopyValueAtIndex(friendAddressSet,0);
        friendZip = [friendFirstAddress objectForKey:@"ZIP"];
        [self centerMap:friendZip showAddress:friendFirstAddress];
		[friendFirstAddress release];
    }
    
    ABMultiValueRef friendEmailAddresses;
    friendEmailAddresses = ABRecordCopyValue(person, kABPersonEmailProperty);
    
    if (ABMultiValueGetCount(friendEmailAddresses)>0) {
        friendEmail=(NSString *)ABMultiValueCopyValueAtIndex(friendEmailAddresses, 0);
        email.text = friendEmail;
        [friendEmail release];
    }
    
	if (ABPersonHasImageData(person)) {
		photo.image = [UIImage imageWithData:
                       (NSData *)ABPersonCopyImageData(person)];
	}
	
    [self dismissModalViewControllerAnimated:YES];
	return NO;
}

- (BOOL)peoplePickerNavigationController:
(ABPeoplePickerNavigationController *)peoplePicker
      shouldContinueAfterSelectingPerson:(ABRecordRef)person
                                property:(ABPropertyID)property
                              identifier:(ABMultiValueIdentifier)identifier {
    //We won't get to this delegate method
	
    return NO;
}



/*
// The designated initializer. Override to perform setup that is required before the view is loaded.
- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
    if ((self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil])) {
        // Custom initialization
    }
    return self;
}
*/

/*
// Implement loadView to create a view hierarchy programmatically, without using a nib.
- (void)loadView {
}
*/


/*
// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad {
    [super viewDidLoad];
}
*/


/*
// Override to allow orientations other than the default portrait orientation.
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}
*/

- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;
}


- (void)dealloc {
    [name release];
    [email release];
    [photo release];
    [map release];
    [super dealloc];
}

@end
