//
//  CupertinoViewController.m
//  Cupertino
//
//  Created by John E. Ray on 7/17/10.
//  Copyright John E. Ray 2010. All rights reserved.
//

#import "CupertinoViewController.h"

#define kCupertinoLatitude  37.3229978
#define kCupertinoLongitude -122.0321823
#define deg2rad 0.0174532925
#define rad2deg 57.2957795
#define straight 1
#define right 2
#define left 3

@implementation CupertinoViewController

@synthesize locMan;
@synthesize distanceLabel;
@synthesize distanceView;
@synthesize waitView;
@synthesize recentLocation;
@synthesize directionArrow;



/*
// The designated initializer. Override to perform setup that is required before the view is loaded.
- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
    if ((self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil])) {
        // Custom initialization
    }
    return self;
}
*/

/*
// Implement loadView to create a view hierarchy programmatically, without using a nib.
- (void)loadView {
}
*/

/*
 * According to Movable Type Scripts
 * http://mathforum.org/library/drmath/view/55417.html
 *
 *  Javascript:
 *    
 * var y = Math.sin(dLon) * Math.cos(lat2);
 * var x = Math.cos(lat1)*Math.sin(lat2) -
 * Math.sin(lat1)*Math.cos(lat2)*Math.cos(dLon);
 * var brng = Math.atan2(y, x).toDeg();
 */
-(double)headingToLocation:(CLLocationCoordinate2D)desired
                   current:(CLLocationCoordinate2D)current {
    
    // Gather the variables needed by the heading algorithm
    double lat1 = current.latitude*deg2rad;
    double lat2 = desired.latitude*deg2rad;
    double lon1 = current.longitude;
    double lon2 = desired.longitude;
    double dlon = (lon2-lon1)*deg2rad;
    
    double y = sin(dlon)*cos(lat2);
    double x = cos(lat1)*sin(lat2) - sin(lat1)*cos(lat2)*cos(dlon);
    
    double heading=atan2(y,x);
    heading=heading*rad2deg;
    heading=heading+360.0;
    heading=fmod(heading,360.0);
    return heading;
}

- (void)locationManager:(CLLocationManager *)manager
       didUpdateHeading:(CLHeading *)newHeading {
    
    
    if (self.recentLocation != nil && newHeading.headingAccuracy >= 0) {
        CLLocation *cupertino = [[[CLLocation alloc]
                                  initWithLatitude:kCupertinoLatitude
                                  longitude:kCupertinoLongitude] autorelease];
        double course = [self headingToLocation:cupertino.coordinate
                                        current:recentLocation.coordinate];
        double delta = newHeading.trueHeading - course;
        if (abs(delta) <= 10) {
            directionArrow.image = [UIImage imageNamed:@"up_arrow.png"];
            if (lastSound!=straight) AudioServicesPlaySystemSound(soundStraight);
            lastSound=straight;
        } else {
            if (delta > 180) { 
                directionArrow.image = [UIImage imageNamed:@"right_arrow.png"];
                if (lastSound!=right) AudioServicesPlaySystemSound(soundRight);
                lastSound=right;
            } else if (delta > 0) {
                directionArrow.image = [UIImage imageNamed:@"left_arrow.png"];
                if (lastSound!=left) AudioServicesPlaySystemSound(soundLeft);  
                lastSound=left;
            } else if (delta > -180) { 
                directionArrow.image = [UIImage imageNamed:@"right_arrow.png"];
                if (lastSound!=right) AudioServicesPlaySystemSound(soundRight);  
                lastSound=right;
            } else {
                directionArrow.image = [UIImage imageNamed:@"left_arrow.png"];
                if (lastSound!=left) AudioServicesPlaySystemSound(soundLeft);  
                lastSound=left;
            }
        }
        directionArrow.hidden = NO;
    } else {
        directionArrow.hidden = YES;
    }
    
}


- (void)locationManager:(CLLocationManager *)manager
    didUpdateToLocation:(CLLocation *)newLocation
           fromLocation:(CLLocation *)oldLocation {
	
    if (newLocation.horizontalAccuracy >= 0) {
        
		// Store the location for use during heading updates
        self.recentLocation = newLocation;
		
        CLLocation *cupertino = [[[CLLocation alloc]
                                  initWithLatitude:kCupertinoLatitude
                                  longitude:kCupertinoLongitude] autorelease];
        CLLocationDistance delta = [cupertino distanceFromLocation: newLocation];
        long miles = (delta * 0.000621371) + 0.5; // meters to rounded miles
        if (miles < 3) {
			// Turn off the location manager updates
            [manager stopUpdatingLocation];
            [manager stopUpdatingHeading];
			
            // Congratulate the user
            distanceLabel.text = @"Enjoy the\nMothership!";
        } else {
            NSNumberFormatter *commaDelimited = [[[NSNumberFormatter alloc]
												  init] autorelease];
            [commaDelimited setNumberStyle:NSNumberFormatterDecimalStyle];
            distanceLabel.text = [NSString stringWithFormat:
                                  @"%@ miles to the\nMothership",
                                  [commaDelimited stringFromNumber:
								   [NSNumber numberWithLong:miles]]];
        }
        waitView.hidden = YES;
        distanceView.hidden = NO;
    }   
}


- (void)locationManager:(CLLocationManager *)manager
       didFailWithError:(NSError *)error {
	
    if (error.code == kCLErrorDenied) {
        // Turn off the location manager updates
        [manager stopUpdatingLocation];
        [locMan release];
        locMan = nil;
    }
    waitView.hidden = YES;
    distanceView.hidden = NO; 
}


- (void)viewDidLoad {
    [super viewDidLoad];
    
    NSString *soundFile;
    
    soundFile = [[NSBundle mainBundle] 
                  pathForResource:@"straight" ofType:@"wav"];
    AudioServicesCreateSystemSoundID((CFURLRef)
                [NSURL fileURLWithPath:soundFile]
                ,&soundStraight);
    [soundFile release];
    
    soundFile = [[NSBundle mainBundle] 
                  pathForResource:@"right" ofType:@"wav"];
    AudioServicesCreateSystemSoundID((CFURLRef)
                [NSURL fileURLWithPath:soundFile]
                ,&soundRight);
    [soundFile release];
    
    soundFile = [[NSBundle mainBundle] 
                  pathForResource:@"left" ofType:@"wav"];
    AudioServicesCreateSystemSoundID((CFURLRef)
                [NSURL fileURLWithPath:soundFile]
                ,&soundLeft);
    [soundFile release];
    lastSound=0;
        
    locMan = [[CLLocationManager alloc] init];
    locMan.delegate = self;
    locMan.desiredAccuracy = kCLLocationAccuracyThreeKilometers;
    locMan.distanceFilter = 1609; // a mile 
    [locMan startUpdatingLocation];
    if ([CLLocationManager headingAvailable]) {
        locMan.headingFilter = 15; // 10 degrees
        [locMan startUpdatingHeading];
    } 
    
}



/*
// Override to allow orientations other than the default portrait orientation.
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}
*/

- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;
}


- (void)dealloc {
	[locMan release];
    [distanceLabel release];
    [distanceView release];
    [waitView release];	
	[recentLocation release];
	[directionArrow release];
    [super dealloc];
}

@end
